:mod:`maec.package.malware_subject_reference` Module
====================================================

.. module:: maec.package.malware_subject_reference

Classes
-------

.. autoclass:: MalwareSubjectReference
	:show-inheritance:
	:members:
